@@ -1,27 +1,38 @@
 /*
-   This file is part of the KDE games kwin4 program
-   Copyright (c) 1995-2007 Martin Heni <kde@heni-online.de>
+    This file is part of the KDE games kwin4 program
+    SPDX-FileCopyrightText: 1995-2007 Martin Heni <kde@heni-online.de>
 
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-// Header includes
 #include "kwin4.h"
 
-// Qt includes
+// own
+#include "chatdlg.h"
+#include "kwin4doc.h"
+#include "kwin4view.h"
+#include "reflectiongraphicsscene.h"
+#include "prefs.h"
+#include "ui_settings.h"
+#include "ui_statistics.h"
+#include "kfourinline_debug.h"
+#include "kgamedialog.h"
+#include "kgamedialogconfig.h"
+#include "kgamedebugdialog.h"
+// KDEGames
+#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
+#include <libkdegamesprivate/kgame/kgamechat.h>
+// KF
+#include <kwidgetsaddons_version.h>
+#include <KActionCollection>
+#include <KConfig>
+#include <KConfigDialog>
+#include <KLocalizedString>
+#include <KMessageBox>
+#include <KSelectAction>
+#include <KStandardAction>
+#include <KStandardGameAction>
+// Qt
 #include <QFileDialog>
 #include <QGroupBox>
 #include <QIcon>
@@ -31,32 +42,6 @@
 #include <QTimer>
 #include <QVBoxLayout>
 
-// KDE includes
-#include <KActionCollection>
-#include <KConfig>
-#include <KConfigDialog>
-#include <KLocalizedString>
-#include <KMessageBox>
-#include <KSelectAction>
-#include <KStandardAction>
-#include <KStandardGameAction>
-
-// KGame includes
-#define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
-#include <libkdegamesprivate/kgame/kgamechat.h>
-#include "kgamedialog.h"
-#include "kgamedialogconfig.h"
-#include "kgamedebugdialog.h"
-
-// application specific includes
-#include "chatdlg.h"
-#include "kwin4doc.h"
-#include "kwin4view.h"
-#include "reflectiongraphicsscene.h"
-#include "prefs.h"
-#include "ui_settings.h"
-#include "ui_statistics.h"
-#include "kfourinline_debug.h"
 
 // Abbreviations
 #define ACTION(x)   (actionCollection()->action(x))
@@ -307,13 +292,13 @@ void KWin4App::initGUI()
   QAction* action;
 
   // Game
-  KStandardGameAction::gameNew(this, SLOT(menuNewGame()), actionCollection());
-  KStandardGameAction::load(this, SLOT(menuOpenGame()), actionCollection());
-  KStandardGameAction::save(this, SLOT(menuSaveGame()), actionCollection());
-  action = KStandardGameAction::end(this, SLOT(endGame()), actionCollection());
+  KStandardGameAction::gameNew(this, &KWin4App::menuNewGame, actionCollection());
+  KStandardGameAction::load(this, &KWin4App::menuOpenGame, actionCollection());
+  KStandardGameAction::save(this, &KWin4App::menuSaveGame, actionCollection());
+  action = KStandardGameAction::end(this, &KWin4App::endGame, actionCollection());
   action->setWhatsThis(i18n("Ends a currently played game. No winner will be declared."));
-  KStandardGameAction::hint(this, SLOT(askForHint()), actionCollection());
-  KStandardGameAction::quit(this, SLOT(close()), actionCollection());
+  KStandardGameAction::hint(this, &KWin4App::askForHint, actionCollection());
+  KStandardGameAction::quit(this, &KWin4App::close, actionCollection());
   
   action = actionCollection()->addAction( QStringLiteral( "network_conf" ));
   action->setText(i18n("&Network Configuration..."));
@@ -330,10 +315,10 @@ void KWin4App::initGUI()
   action->setToolTip(i18n("Show statistics."));
 
   // Move
-  KStandardGameAction::undo(this, SLOT(undoMove()), actionCollection());
-  KStandardGameAction::redo(this, SLOT(redoMove()), actionCollection());
+  KStandardGameAction::undo(this, &KWin4App::undoMove, actionCollection());
+  KStandardGameAction::redo(this, &KWin4App::redoMove, actionCollection());
 
-  actionCollection()->addAction(KStandardAction::Preferences, this, SLOT(configureSettings()));
+  KStandardAction::preferences(this, &KWin4App::configureSettings, actionCollection());
 
   // Add all theme files to the menu
   QStringList themes(mThemeFiles.keys());
@@ -343,7 +328,11 @@ void KWin4App::initGUI()
   actionCollection()->addAction( QStringLiteral( "theme" ) , themeAction );
   themeAction->setIcon(QIcon::fromTheme( QStringLiteral( "games-config-theme" )));
   themeAction->setItems(themes);
+#if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 78, 0)
+  connect(themeAction, &KSelectAction::indexTriggered, this, &KWin4App::changeTheme);
+#else
   connect(themeAction, static_cast<void (KSelectAction::*)(int)>(&KSelectAction::triggered), this, &KWin4App::changeTheme);
+#endif
   qCDebug(KFOURINLINE_LOG) << "Setting current theme item to" << mThemeIndexNo;
   themeAction->setCurrentItem(mThemeIndexNo);
 
